@@ -70,6 +70,12 @@ class Task:
             x += t.getPoints()
         return x
 
+    def getScore(self):
+        x = 0
+        for t in self.subtasks.values():
+            x += t.getScore()
+        return x
+
     def setSolution(self, solution):
         self.solution = solution
     
@@ -110,6 +116,12 @@ class SubTask:
     def getPoints(self):
         return self.points
 
+    def setScore(self, score):
+        self.score = score
+
+    def getScore(self, score):
+        return self.score
+
     def setSolution(self, solution):
         self.solution = solution
     
